---
name: Merge to other developers branch
about: Template for merging to another dev's branch
title: 'chore: Replace me using the semantic release commit format.'
---

# Summary

## Quality assurance (at the discretion of the branch owner)

- [ ] My code follows the code style of this project.
- [ ] Documentation for my change is up to date?
- [ ] My PR meets testing requirements.
- [ ] All new and existing tests passed.
- [ ] All commits are signed-off.
